==> netgen_mesher-6.2.2404.post72-cp39-cp39-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: netgen_mesher-6.2.2404.post72.data/data/lib/python3.9/site-packages/netgen/config/config.py <==
def _cmake_to_bool(s):
    return s.upper() not in ['', '0','FALSE','OFF','N','NO','IGNORE','NOTFOUND']

is_python_package    = _cmake_to_bool("TRUE")

BUILD_FOR_CONDA     = _cmake_to_bool("ON")
BUILD_STUB_FILES    = _cmake_to_bool("ON")
CHECK_RANGE         = _cmake_to_bool("OFF")
DEBUG_LOG           = _cmake_to_bool("OFF")
ENABLE_CPP_CORE_GUIDELINES_CHECK  = _cmake_to_bool("OFF")
ENABLE_UNIT_TESTS   = _cmake_to_bool("OFF")
INSTALL_PROFILES    = _cmake_to_bool("OFF")
INTEL_MIC           = _cmake_to_bool("OFF")
TRACE_MEMORY        = _cmake_to_bool("OFF")
USE_CCACHE          = _cmake_to_bool("ON")
USE_CGNS            = _cmake_to_bool("OFF")
USE_GUI             = _cmake_to_bool("ON")
USE_INTERNAL_TCL    = _cmake_to_bool("ON")
USE_JPEG            = _cmake_to_bool("OFF")
USE_MPEG            = _cmake_to_bool("OFF")
USE_MPI             = _cmake_to_bool("ON")
USE_MPI4PY          = _cmake_to_bool("")
USE_NATIVE_ARCH     = _cmake_to_bool("OFF")
USE_NUMA            = _cmake_to_bool("OFF")
USE_OCC             = _cmake_to_bool("ON")
USE_PYTHON          = _cmake_to_bool("ON")
USE_SPDLOG          = _cmake_to_bool("")

CMAKE_INSTALL_PREFIX  = "/builds/ngsolve/netgen/_skbuild/linux-x86_64-3.9/cmake-install"
NG_INSTALL_DIR_PYTHON   = "lib/python3.9/site-packages"
NG_INSTALL_DIR_BIN      = "bin"
NG_INSTALL_DIR_LIB      = "lib/python3.9/site-packages/netgen_mesher.libs"
NG_INSTALL_DIR_INCLUDE  = "include/netgen"
NG_INSTALL_DIR_CMAKE    = "lib/cmake/netgen"
NG_INSTALL_DIR_RES      = "share"

NETGEN_PYTHON_RPATH_BIN = "../../../bin"
NETGEN_PYTHON_RPATH     = "netgen_mesher.libs"
NETGEN_PYTHON_PACKAGE_NAME = "netgen-mesher"

NG_COMPILE_FLAGS           = "-march=core-avx2"
ngcore_compile_options     = "-march=core-avx2;-fabi-version=14"
ngcore_compile_definitions = "_GLIBCXX_USE_CXX11_ABI=0;NETGEN_PYTHON;NG_PYTHON;PYBIND11_SIMPLE_GIL_MANAGEMENT;PARALLEL;NG_MPI_WRAPPER"

NETGEN_VERSION = "6.2.2404-72-ga504372f"
NETGEN_VERSION_GIT = "v6.2.2404-72-ga504372f"
NETGEN_VERSION_PYTHON = "6.2.2404.post72"

NETGEN_VERSION_MAJOR = "6"
NETGEN_VERSION_MINOR = "2"
NETGEN_VERSION_TWEAK = "72"
NETGEN_VERSION_PATCH = "2404"
NETGEN_VERSION_HASH = "ga504372f"

PYTHON_VERSION       = "3.9.19"
PYTHON_VERSION_MAJOR = "3"
PYTHON_VERSION_MINOR = "9"

version = NETGEN_VERSION_GIT

def get_cmake_dir():
    import os.path as p
    d_python = p.dirname(p.dirname(p.dirname(__file__)))
    py_to_cmake = p.relpath(
            NG_INSTALL_DIR_CMAKE,
            NG_INSTALL_DIR_PYTHON
            )
    return p.normpath(p.join(d_python,py_to_cmake))

==> netgen_mesher-6.2.2405.post32.dev0-cp39-cp39-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: netgen_mesher-6.2.2405.post32.dev0.data/data/lib/python3.9/site-packages/netgen/config/config.py <==
def _cmake_to_bool(s):
    return s.upper() not in ['', '0','FALSE','OFF','N','NO','IGNORE','NOTFOUND']

is_python_package    = _cmake_to_bool("TRUE")

BUILD_FOR_CONDA     = _cmake_to_bool("ON")
BUILD_STUB_FILES    = _cmake_to_bool("ON")
CHECK_RANGE         = _cmake_to_bool("OFF")
DEBUG_LOG           = _cmake_to_bool("OFF")
ENABLE_CPP_CORE_GUIDELINES_CHECK  = _cmake_to_bool("OFF")
ENABLE_UNIT_TESTS   = _cmake_to_bool("OFF")
INSTALL_PROFILES    = _cmake_to_bool("OFF")
INTEL_MIC           = _cmake_to_bool("OFF")
TRACE_MEMORY        = _cmake_to_bool("OFF")
USE_CCACHE          = _cmake_to_bool("ON")
USE_CGNS            = _cmake_to_bool("OFF")
USE_GUI             = _cmake_to_bool("ON")
USE_INTERNAL_TCL    = _cmake_to_bool("ON")
USE_JPEG            = _cmake_to_bool("OFF")
USE_MPEG            = _cmake_to_bool("OFF")
USE_MPI             = _cmake_to_bool("ON")
USE_MPI4PY          = _cmake_to_bool("")
USE_NATIVE_ARCH     = _cmake_to_bool("OFF")
USE_NUMA            = _cmake_to_bool("OFF")
USE_OCC             = _cmake_to_bool("ON")
USE_PYTHON          = _cmake_to_bool("ON")
USE_SPDLOG          = _cmake_to_bool("")

CMAKE_INSTALL_PREFIX  = "/builds/ngsolve/ngsolve/external_dependencies/netgen/_skbuild/linux-x86_64-3.9/cmake-install"
NG_INSTALL_DIR_PYTHON   = "lib/python3.9/site-packages"
NG_INSTALL_DIR_BIN      = "bin"
NG_INSTALL_DIR_LIB      = "lib/python3.9/site-packages/netgen_mesher.libs"
NG_INSTALL_DIR_INCLUDE  = "include/netgen"
NG_INSTALL_DIR_CMAKE    = "lib/cmake/netgen"
NG_INSTALL_DIR_RES      = "share"

NETGEN_PYTHON_RPATH_BIN = "../../../bin"
NETGEN_PYTHON_RPATH     = "netgen_mesher.libs"
NETGEN_PYTHON_PACKAGE_NAME = "netgen-mesher"

NG_COMPILE_FLAGS           = "-march=core-avx2"
ngcore_compile_options     = "-march=core-avx2;-fabi-version=17"
ngcore_compile_definitions = "_GLIBCXX_USE_CXX11_ABI=1;NETGEN_PYTHON;NG_PYTHON;PYBIND11_SIMPLE_GIL_MANAGEMENT;PARALLEL;NG_MPI_WRAPPER"

NETGEN_VERSION = "6.2.2405-32-g141af428"
NETGEN_VERSION_GIT = "v6.2.2405-32-g141af428"
NETGEN_VERSION_PYTHON = "6.2.2405.post32.dev0"

NETGEN_VERSION_MAJOR = "6"
NETGEN_VERSION_MINOR = "2"
NETGEN_VERSION_TWEAK = "32"
NETGEN_VERSION_PATCH = "2405"
NETGEN_VERSION_HASH = "g141af428"

PYTHON_VERSION       = "3.9.19"
PYTHON_VERSION_MAJOR = "3"
PYTHON_VERSION_MINOR = "9"

version = NETGEN_VERSION_GIT

def get_cmake_dir():
    import os.path as p
    d_python = p.dirname(p.dirname(p.dirname(__file__)))
    py_to_cmake = p.relpath(
            NG_INSTALL_DIR_CMAKE,
            NG_INSTALL_DIR_PYTHON
            )
    return p.normpath(p.join(d_python,py_to_cmake))
